### Name: mprobit
### Title: Maximum Likelihood for Repeated Measures Multivariate Binary
###   Probit Model
### Aliases: mprobit mprobit.formula mprobit.exch mprobit.ar mprobit.unstr
### Keywords: models

### ** Examples

# first test data set
data(binaryex)
x=binaryex$x
y=binaryex$y
id=binaryex$id

# various ways of using mprobit are shown here
# exchangeable dependence 
out.exch = mprobit.exch(x,y,id)
print(out.exch)

# AR(1) dependence 
out.ar = mprobit(x,y,id,corstr="ar")
print(out.ar)

# unstructured correlation matrix
out.unstr = mprobit.formula(y~x,binaryex$id,data=binaryex,corstr="unstr")
print(out.unstr)

# second test data set
data(binaryar)
dat=binaryar
x=dat$x
y=dat$y
id=dat$id
x2=x*x
dat$x2=x2

# exchangeable dependence 
out2.exch = mprobit.exch(cbind(x,x2),y,id)
print(out2.exch)

# AR(1) dependence 
out2.ar = mprobit.formula(y~x+x2,dat$id,data=dat,corstr="ar")
print(out2.ar)

# varying cluster sizes
set.seed(123)
ncl=nrow(dat)/4
idel=sort(sample(ncl,ncl/4))
idel=idel*4
datsub=dat[-idel,]
out3.ar = mprobit.formula(y~x+x2,datsub$id,data=datsub,corstr="ar")
print(out3.ar)



